@@ -7,31 +7,44 @@ import config
 
 headers = {'content-type': 'application/json'}
 
-def read_and_report_adafruit_scd4x(scd4x):
+
+def get_device_metadata():
+    report_data = {}
+    try:
+        time.sleep(1.0)
+        device_id = ubinascii.hexlify(machine.unique_id()).decode()
+        time.sleep(1.0)
+        report_data["device_metadata"] = {
+            "device_id": device_id,
+            "name": config.DEVICE_NAME,
+            "api_key": config.OPEN_SENSOR_API_KEY,
+        }
+    except Exception as e:
+        print(e)
+    return report_data
+
+
+def add_adafruit_scd4x_data_to_report(report_data, temp, rh, ppm_carbon_dioxide):
+    if temp:
+        report_data["temp"] = {
+            "temp": temp,
+            "unit": "C"
+        }
+    if rh:
+        report_data["rh"] = {
+            "rh": rh,
+        }
+    if ppm_carbon_dioxide:
+        report_data["co2"] = {
+            "ppm": ppm_carbon_dioxide,
+        }
+
+
+def report_environment_data(report_data):
     """This method requires installing urequests and ujson from pypi."""
     try:
         import urequests
         import ujson
-        data = sensors.read_adafruit_scd4x(scd4x)
-        time.sleep(1.0)
-        device_id = ubinascii.hexlify(machine.unique_id()).decode()
-        time.sleep(1.0)
-        report_data = {
-            "device_metadata": {
-                "device_id": device_id,
-                "name": config.DEVICE_NAME,
-            },
-            "temp": {
-                "temp": data[0],
-                "unit": "C"
-            },
-            "rh": {
-                "rh": data[1],
-            },
-            "co2": {
-                "ppm": data[2],
-            }
-        }
         time.sleep(1.0)
         resp = urequests.post(
             "https://api.opensensor.io/environment/",
@@ -39,8 +52,5 @@ def read_and_report_adafruit_scd4x(scd4x):
             data=ujson.dumps(report_data))
         print(resp.status_code)
         resp.close()
-        return data
     except Exception as e:
         print(e)
-    return None
-
