@@ -41,7 +41,7 @@ try:
             i2c = machine.I2C(config.DISPLAY_I2C_CHANNEL, scl=scl, sda=sda, freq=100000)
             display = SH1107_I2C(128, 128, i2c, addr=config.DISPLAY_I2C_ADDRESS)
         if config.DISPLAY_SWITCH:
-            switch = machine.Pin(config.DISPLAY_SWITCH, machine.Pin.IN, config.DISPLAY_SWITCH_PULL)
+            switch = machine.Pin(get_gpio_for_mcu(config.DISPLAY_SWITCH), machine.Pin.IN, config.DISPLAY_SWITCH_PULL)
             switch.irq(trigger=config.DISPLAY_SWITCH_TRIGGER, handler=toggle_display)
 except Exception as exc:
     print(f"Exception trying to initialize display: {exc}")
@@ -106,3 +106,24 @@ def display_ph_reading(ph_reading):
             gc.collect()
         except Exception as e:
             print(e)
+
+
+def display_scd4x_reading(temp, rh, ppm_carbon_dioxide):
+    global display
+    print("Temperature: %0.1f *C" % temp)
+    print("Humidity: %0.1f %%" % rh)
+    print("CO2: %d ppm" % ppm_carbon_dioxide)
+    if display:
+        try:
+            gc.collect()
+            display.fill(0)
+            display.text("temp ", 0, 0)
+            display.text(str(temp), 64, 0)
+            display.text("rh ", 0, 32)
+            display.text(str(rh), 64, 32)
+            display.text("CO2 ppm ", 0, 64)
+            display.text(str(ppm_carbon_dioxide), 64, 64)
+            display.show()
+            gc.collect()
+        except Exception as e:
+            print(e)
